SystemOrganization addCategory: #GODTextIOTests!

TestCase subclass: #TXTIOTest
	instanceVariableNames: 'textIO'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODTextIOTests'!

!TXTIOTest commentStamp: 'jlcg 9/27/2014 12:02' prior: 0!
SUnit tests to TXTInterface class.!

!TXTIOTest methodsFor: 'initialize-release' stamp: 'jlcg 10/17/2014 20:02'!
setUp
	textIO := TXTIOConverter new.! !

!TXTIOTest methodsFor: 'tests' stamp: 'jlcg 10/17/2014 21:58'!
testReadFromFileReturn
	"Tests if the return of readFromFile methods is a GODData object."

	| fileName godData |

	fileName := '/tmp/', DateAndTime now asString, '.txt'.

	godData := GODData new.
	godData content: 'teste'.

	textIO write: godData toFile: fileName.

	godData := textIO readFromFile: fileName.
	self assert: (godData isGODData).

	godData := textIO readFromFile: fileName.
	self assert: (godData isGODData).! !

!TXTIOTest methodsFor: 'tests' stamp: 'jlcg 10/17/2014 21:15'!
testReadFromInexistentFile
	"Tests if trying to read contents from an inexistent file throws an exception."

	self should: [ textIO readFromFile: '/home/this_user_must_not_exist/this_file_must_not_exist.txt' ] raise: GODTextIOFileDoesNotExist.
	self should: [ textIO readFromFile: '/home/this_user_must_not_exist/this_file_must_not_exist.txt' type: 'txt' ] raise: GODTextIOFileDoesNotExist.! !

!TXTIOTest methodsFor: 'tests' stamp: 'jlcg 10/17/2014 21:59'!
testWriteToExistentFileOverwrite
	"Tests whether trying to write contents to an existent file with 'overwrite' option set to False throws an exception"

	| fileName godData |

	fileName := '/tmp/', DateAndTime now asString, '.txt'.

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module - Write Overwrite'.

	textIO write: godData toFile: fileName type: 'txt'.

	self should: [ textIO write: godData toFile: fileName type: 'txt' overwrite: false ] raise: GODTextIOFileAlreadyExists.! !

!TXTIOTest methodsFor: 'tests' stamp: 'jlcg 10/17/2014 21:59'!
testWriteToFileAppend
	"Tests the appending operation to an existent file"

	| fileName godData |

	fileName := '/tmp/', DateAndTime now asString, '.txt'.

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module - Write Append'.

	textIO write: godData toFile: fileName type: 'txt'.

	godData content: 'Test from Text Processing module - Appending data'.
	self assert: ( textIO write: godData toFile: fileName type: 'txt' append: true ).! !

!TXTIOTest methodsFor: 'tests' stamp: 'jlcg 10/17/2014 21:57'!
testWriteToFileBasic
	"Tests write: toFile: method, and its variants"

	| godData |

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module'.	

	self assert: ( textIO write: godData toFile: '/tmp/', DateAndTime now asString, '_1.txt' ).
	self assert: ( textIO write: godData toFile: '/tmp/', DateAndTime now asString, '_2.txt' type: 'txt' ).
	self assert: ( textIO write: godData toFile: '/tmp/', DateAndTime now asString, '_3.txt' type: 'txt' append: false ).
	self assert: ( textIO write: godData toFile: '/tmp/', DateAndTime now asString, '_4.txt' type: 'txt' overwrite: false ).! !

!TXTIOTest methodsFor: 'tests' stamp: 'jlcg 10/17/2014 22:00'!
testWriteToFileOverwrite
	"Tests overwriting operation on an existent file"

	| fileName godData |

	fileName := '/tmp/', DateAndTime now asString, '.txt'.

	godData := GODData new.
	godData origin: 'TextIO'.
	godData content: 'Test from Text Processing module - Write Overwrite'.

	textIO write: godData toFile: fileName type: 'txt'.

	godData content: 'Test from Text Processing module - Overwrite content'.

	self assert: ( textIO write: godData toFile: fileName type: 'txt' overwrite: true ).! !

!TXTIOTest methodsFor: 'tests' stamp: 'jlcg 10/17/2014 21:44'!
testWriteToNonexistentFileAppend
	"Tests whether trying to append contents to a nonexistent file throws an exception"

	| godData |

	godData := GODData new.

	self should: [ textIO write: godData toFile: '/tmp/test_append_nonexistent.txt' type: 'txt' append: true ] raise: GODTextIOFileDoesNotExist.! !
